from setuptools import setup

setup(name='qama_distr',
      version='0.1',
      description='Gaussian distributions',
      packages=['qama_distr'],
      author = 'Qamarudeen Muhammad',
      email = 'crescentgroup2000@gmail.com',
      zip_safe=False)
